/*-*- c++ -*-******************************************************************
 * Qwt Widget Library 
 * Copyright (C) 1997   Josef Wilgen
 * 
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Lesser General Public
 * License as published by the Free Software Foundation; either
 * version 2.1 of the License, or (at your option) any later version.
 * 
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Lesser General Public License for more details.
 * 
 * You should have received a copy of the GNU Lesser General Public
 * License along with this library; if not, write to the Free Software
 * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 *****************************************************************************/

#ifndef QWT_PLOT_LAYOUT_H
#define QWT_PLOT_LAYOUT_H

#include <qlayout.h>
#include "qwt_global.h"
#include "qwt_plot.h"

class QwtPlotLayoutData;

/*!
  \brief Layout class for QwtPlot.

  Organizes the geometry for the different QwtPlot components.
*/

class QWT_EXPORT QwtPlotLayout
{
public:
    enum Options
    {
        IgnoreScrollbars = 1,
        AlignScales = 2,
        IgnoreFrames = 4
    };

    QwtPlotLayout();
    virtual ~QwtPlotLayout();

    void setMargin(int);
    int margin() const;

    void setSpacing(int);
    int spacing() const;

    void setLegendPos(int pos);
    int legendPos() const;

    virtual QSize minimumSizeHint(
        const QLabel *, 	
#ifndef QWT_NO_LEGEND
		const QwtLegend *, 
#endif
        const QwtScale *[QwtPlot::axisCnt],
		const QwtPlotCanvas *) const;

    virtual void activate( const QRect &rect,
        const QwtPlotPrintFilter &, 
        const QLabel *, 
#ifndef QWT_NO_LEGEND
		const QwtLegend *, 
#endif
        const QwtScale *[QwtPlot::axisCnt], const QwtPlotCanvas *,
        int options = 0);

    virtual void invalidate();

    const QRect &titleRect() const;
    const QRect &legendRect() const;
    const QRect &scaleRect(int axis) const;
    const QRect &canvasRect() const;

protected:

#ifndef QWT_NO_LEGEND
    QRect layoutLegend(int options, const QRect &) const;
    QRect alignLegend(int options, 
        const QRect &canvasRect, const QRect &legendRect) const;
#endif

    void expandLineBreaks(int options, const QRect &rect, 
        int &dimTitle, int dimAxes[QwtPlot::axisCnt]) const;

    void alignScales(int options,
        QRect scaleRect[QwtPlot::axisCnt]) const;

    QRect d_titleRect;
    QRect d_legendRect;
    QRect d_scaleRect[QwtPlot::axisCnt];
    QRect d_canvasRect;

    QwtPlotLayoutData *d_layoutData;

private:
    int d_options;

    int d_legendPos;
    unsigned int d_margin;
    unsigned int d_spacing;
    unsigned int d_canvasMargin;
};

#endif
