#!/usr/bin/env python

import os, sys

# EDIT the Windows or Linux/Unix section to reflect your system:
# qt_dir -- must contain your Qt distribution (headers, binaries, libraries)
# sip_program -- must be the full path to the sip program
# sip_spec_dirs -- must contain the files 'qtmod.sip' & friends

if os.name == 'nt':
    # Windows-95, -98, ...
    # My PyQwt build procedure is (see HTML documentation):
    # (1) build and install sip from source
    # (2) build and install PyQt manually from source
    # (3) build PyQwt from source
    sip_extra_dirs = ['C:\MyStuff\PyQt-win-nc-3.5\sip']
    sip_program = 'sip.exe'   # is OK, sip.exe and python.exe on the same PATH.
    extra_compile_args = []   # is OK.
    doc_dir = 'Doc\PyQwt-3.5' # is OK, ends up in C:\Python22\Doc.
elif os.name == 'posix':
    # Linux/Unix
    sip_program = '/usr/bin/sip'
    sip_extra_dirs = ['/usr/share/sip/qt']
    extra_compile_args = [ '-fno-exceptions' ]
    doc_dir = '/usr/share/doc/PyQwt-3.5'
else:
    raise SystemExit, "You are trying to install PyQwt on an unsupported OS."

# Select a Qwt snapshot
# - warning: *.moc and *.sip files have to be regenerated.
# - hint:    read the Makefile or do 'make force'
qwt_version = '-20021013' # bleeding edge
qwt_version = '-20020807' # I use this snapshot everyday 

#
# IF YOU NEED TO EDIT BELOW THIS LINE -- IT IS A BUG
#

#
# VERSION INFORMATION
#

from qt import qVersion #, PYQT_VERSION

QT_VERSION = qVersion()
version = '3.5'
qwtdir = 'qwt' + qwt_version
sip_source_dir = 'sip' + qwt_version

#
# CHECK FOR QTDIR
#

try:
    os.environ['QTDIR']
except KeyError:
    raise SystemExit, \
          "Failed to build PyQwt.\nPlease, " \
          "set the environment variable QTDIR to your Qt directory. E.g:\n" \
          "(1) on Windows:\n\tset QTDIR=C:\QT\n" \
          "(2) bash, ksh, zsh of sh:\n\texport QTDIR=/usr/lib/qt3\n" \
          "(3) csh or tcsh:\n\tsetenv QTDIR /usr/lib/qt3\n"

#
# CHECK FOR A RECENT PYTHON
#

if not hasattr(sys, 'version_info') or sys.version_info < (2,0,0, 'alpha', 0):
    raise SystemExit, 'Python-2.0 or later required to build PyQwt.'

#
# REAL WORK
#

# pyqt_support.py uses this (replaces command line switches)
file = open('setup.cfg', 'w')
file.write('[build_ext]\n')
file.write('sip_program=%s\n' % sip_program)
file.close()

# postpone costly module imports as much possible
from distutils.core import setup
from distutils.file_util import copy_file
from distutils.sysconfig import get_python_inc
from glob import glob
from os.path import join

from pyqt_support import PyQtExtension, build_ext_pyqt

#
# EXTENSION MODULE INFO
#

source_files = glob(join(qwtdir, 'src', '*.cpp'))
source_files.append(join('numeric', 'qwt_numeric.cpp'))

pyQwt = PyQtExtension('PyQwt.qwt',
                      source_files,
                      sip_source_dir = sip_source_dir,
                      sip_extra_dirs = sip_extra_dirs,
                      moc_headers = ['%s/include/qwt_counter.h' % qwtdir,
                                     '%s/include/qwt_legend.h' % qwtdir,
                                     '%s/include/qwt_plot.h' % qwtdir,
                                     '%s/include/qwt_plot_canvas.h' % qwtdir,
                                     '%s/include/qwt_sldbase.h' % qwtdir,
                                     '%s/include/qwt_thermo.h' % qwtdir,
                                     '%s/include/qwt_wheel.h' % qwtdir ],
                      include_dirs = ['numeric', '%s/include' % qwtdir],
                      extra_compile_args = extra_compile_args)

#
# PACKAGE INFO
#

# examples
for file in glob('examples%s/*.py' % QT_VERSION[0]):
    copy_file(file, 'examples')

data_files = [(os.path.join(doc_dir, 'examples'), ['examples/README'])]
if os.name == 'nt':
    for filename in ['BodeDemo.py',
                     'CPUplot.py',
                     'CurveDemo1.py',
                     'CurveDemo2.py',
                     'CurveDemo3.py',
                     'DataDemo.py',
                     'HistTool.py',
                     'ListArrayDemo.py',
                     'MinPackDemo.py',
                     'PyCute.py',
                     'Pythagoras.py',
                     'RadioDemo.py',
                     'SimpleDemo.py',
                     'SliderDemo.py']:
        copy_file('examples/%s' % filename, 'examples/%sw' % filename)
    data_files.append(
        (os.path.join(doc_dir, 'examples'), glob('examples/*.pyw')))
elif os.name == 'posix':
    data_files.append(
        (os.path.join(doc_dir, 'examples'), glob('examples/*.py')))
else:
    raise SystemExit, "You are trying to install PyQwt on an unsupported OS."

# pyuic examples
pyuic_files =  ['LegendBaseDialog.py',
                'LegendBaseDialog.ui',
                'LegendDialog.py',
                'QwtCounter.cw',
                'QwtCounter.xpm',
                'QwtPlot.cw',
                'QwtPlot.xpm',
                'README',
                'make.py']

pyuic_dir = 'pyuic%s' % QT_VERSION[0]
data_files.append((os.path.join(doc_dir, 'pyuic'),
                   map(lambda x: os.path.join(pyuic_dir, x), pyuic_files)))

# scripts
if os.name == 'nt':
    copy_file('examples/PyCute.py', 'examples/PyCute.pyw')
    scripts = ['examples/PyCute.pyw', 'examples/PyCute.bat']
elif os.name == 'posix':
    copy_file('examples/PyCute.py', 'examples/PyCute')
    scripts = ['examples/PyCute']
else:
    raise SystemExit, "You are trying to install PyQwt on an unsupported OS."
    
# documentation
data_files.append(
    (os.path.join(doc_dir, 'PyQwtDoc'), glob(join('doc', 'PyQwt', '*.html'))))
data_files.append(
    (os.path.join(doc_dir, 'QwtDoc'), glob(join(qwtdir, 'doc', 'html', '*'))))


if os.name == 'nt':
    long_description = """
PyQwt = FAST and EASY data plotting for Python, Numeric and Qt!

This version of PyQwt is only for NON-COMMERCIAL use due to the
licensing restrictions of Qt and PyQt.

Html documentation and example scripts can be found in
C:/Python22/Doc/PyQwt-3.5.

C:/Python22/Scripts contains PyCute: a Python shell for PyQt.
"""
elif os.name == 'posix':
    long_description = """
PyQwt = FAST and EASY data plotting for Python, Numeric and Qt!
"""
else:
    raise SystemExit, "You are trying to install PyQwt on an unsupported OS."


long_description = long_description + """
PyQwt is a set of Python bindings for the Qwt C++ class library.
The Qwt library extends the Qt framework with widgets for
Scientific and Engineering applications.  Beside a 2D plot widget
it provides scales, sliders, thermometers, wheels and knobs to
control or display values, arrays, or ranges of type double.

PyQwt requires and extends PyQt, a set of Python bindings for Qt.

PyQwt requires Numeric.  Numeric extends the Python language
with new data types that make Python an ideal language for
numerical computing and experimentation (maybe less efficient
than MatLab, but more expressive).  
"""

setup(name              = "PyQwt",
      version           = version,
      license           = "LGPL",
      url               = "http://gerard.vermeulen.free.fr",
      author            = "Gerard Vermeulen",
      author_email      = "gvermeul@grenoble.cnrs.fr",
      description       = "Python bindings for the Qwt library",
      long_description  = long_description,
      cmdclass          = {'build_ext': build_ext_pyqt},
      packages          = ['qwt'],
      package_dir       = {'qwt': 'lib-qwt'},
      ext_modules       = [pyQwt],
      data_files        = data_files,
      scripts           = scripts)

# Local Variables: ***
# compile-command: "python setup.py build" ***
# End: ***
